FrameIndex

Struct FrameIndex 

pub struct FrameIndex<T>(/* private fields */);
Represents a frame index.

Implementations

Source

impl<T> FrameIndex<T>

pub fn new(value: T) -> Self

Creates a new FrameIndex from the given value.

pub const fn index(&self) -> T
where T: Copy,

Returns the raw frame value.

pub fn into_index(self) -> T

Consumes this FrameIndex value and returns the inner frame value.

pub fn from_time<S>(time: Time<S>, rate: FrameRate<S>) -> Self
where S: Copy + Mul<Output = S> + Floor + SaturatingCast<T>,

Creates a FrameIndex from Time at the specified FrameRate.

pub fn to_time<S>(self, rate: FrameRate<S>) -> Time<S>
where T: Copy + LossyCast<S>, S: Copy + Div<Output = S>,

Converts this FrameIndex to Time at the specified FrameRate.

pub fn offset_from(self, other: Self) -> <T as SignedEquivalent>::Signed

Returns the signed frame offset from this index to another index. The result is positive when self is ahead of other, negative when behind, and zero when equal.

pub fn next(&self) -> Self
where T: One + SaturatingAdd<Output = T>, Self: Copy + SaturatingAdd<T, Output = Self>,

Returns the next FrameIndex, saturating at T::MAX.

pub fn previous(&self) -> Self
where T: One + SaturatingSub<Output = T>, Self: Copy + SaturatingSub<T, Output = Self>,

Returns the previous FrameIndex, saturating at T::MIN.

Source

impl<T> FrameIndex<T>
where T: Zero,

pub const ZERO: Self

Returns the zero.

Source

impl<T> FrameIndex<T>
where T: BoundedMin,

pub const MIN: Self

Returns the minimum value.

Source

impl<T> FrameIndex<T>
where T: BoundedMax,

pub const MAX: Self

Returns the maximum value.

Source

impl<T> FrameIndex<T>
where T: MinMax,

pub fn min(self, other: Self) -> Self

Returns the minimum of two values.

pub fn max(self, other: Self) -> Self

Returns the maximum of two values.

Source

impl<T> FrameIndex<T>
where T: SaturatingAdd<Output = T>,

pub fn saturating_add(self, rhs: Self) -> Self

Returns the result of saturating addition of two FrameIndex values.

pub fn saturating_add_t(self, rhs: T) -> Self

Returns the result of saturating addition of a FrameIndex value and a raw frame value.

Source

impl<T> FrameIndex<T>
where T: SaturatingSub<Output = T>,

pub fn saturating_sub(self, rhs: Self) -> Self

Returns the result of saturating subtraction of two FrameIndex values.

pub fn saturating_sub_t(self, rhs: T) -> Self

Returns the result of saturating subtraction of a FrameIndex value and a raw frame value.