pub struct FrameIndex<T>(/* private fields */);Expand description
Represents a frame index.
Implementations
Sourceimpl<T> FrameIndex<T>
impl<T> FrameIndex<T>
Sourcepub fn new(value: T) -> Self
pub fn new(value: T) -> Self
Creates a new FrameIndex from the given value.
Sourcepub fn into_index(self) -> T
pub fn into_index(self) -> T
Consumes this FrameIndex value and returns the inner frame value.
Sourcepub fn from_time<S>(time: Time<S>, rate: FrameRate<S>) -> Self
pub fn from_time<S>(time: Time<S>, rate: FrameRate<S>) -> Self
Creates a FrameIndex from Time at the specified FrameRate.
Sourcepub fn to_time<S>(self, rate: FrameRate<S>) -> Time<S>
pub fn to_time<S>(self, rate: FrameRate<S>) -> Time<S>
Converts this FrameIndex to Time at the specified FrameRate.
Sourcepub fn offset_from(self, other: Self) -> <T as SignedEquivalent>::Signedwhere
T: SignedEquivalent + SignedCast<<T as SignedEquivalent>::Signed>,
<T as SignedEquivalent>::Signed: Sub<Output = <T as SignedEquivalent>::Signed>,
pub fn offset_from(self, other: Self) -> <T as SignedEquivalent>::Signedwhere
T: SignedEquivalent + SignedCast<<T as SignedEquivalent>::Signed>,
<T as SignedEquivalent>::Signed: Sub<Output = <T as SignedEquivalent>::Signed>,
Returns the signed frame offset from this index to another index. The result is positive when self is ahead of other, negative when behind, and zero when equal.
Sourcepub fn next(&self) -> Self
pub fn next(&self) -> Self
Returns the next FrameIndex, saturating at T::MAX.
Sourcepub fn previous(&self) -> Self
pub fn previous(&self) -> Self
Returns the previous FrameIndex, saturating at T::MIN.
Sourceimpl<T> FrameIndex<T>where
T: BoundedMin,
impl<T> FrameIndex<T>where
T: BoundedMin,
Sourceimpl<T> FrameIndex<T>where
T: BoundedMax,
impl<T> FrameIndex<T>where
T: BoundedMax,
Sourceimpl<T> FrameIndex<T>where
T: MinMax,
impl<T> FrameIndex<T>where
T: MinMax,
Sourceimpl<T> FrameIndex<T>where
T: SaturatingAdd<Output = T>,
impl<T> FrameIndex<T>where
T: SaturatingAdd<Output = T>,
Sourcepub fn saturating_add(self, rhs: Self) -> Self
pub fn saturating_add(self, rhs: Self) -> Self
Returns the result of saturating addition of two FrameIndex values.
Sourcepub fn saturating_add_t(self, rhs: T) -> Self
pub fn saturating_add_t(self, rhs: T) -> Self
Returns the result of saturating addition of a FrameIndex value and a raw frame value.
Sourceimpl<T> FrameIndex<T>where
T: SaturatingSub<Output = T>,
impl<T> FrameIndex<T>where
T: SaturatingSub<Output = T>,
Sourcepub fn saturating_sub(self, rhs: Self) -> Self
pub fn saturating_sub(self, rhs: Self) -> Self
Returns the result of saturating subtraction of two FrameIndex values.
Sourcepub fn saturating_sub_t(self, rhs: T) -> Self
pub fn saturating_sub_t(self, rhs: T) -> Self
Returns the result of saturating subtraction of a FrameIndex value and a raw frame value.